Module token_util

Module token_util 

Structs

ATAToCreate

Functions

find_missing_atas
initialize_atas
Initialize ATAs for all allowed payment tokens for the paymaster This function initializes ATAs for ALL signers in the pool
initialize_atas_with_chunk_size
Initialize ATAs for all allowed payment tokens for the provided addresses with configurable chunk size This function does not use cache and directly checks on-chain