pub struct BundleProcessor {
pub resolved_transactions: Vec<VersionedTransactionResolved>,
pub total_required_lamports: u64,
pub total_payment_lamports: u64,
pub total_solana_estimated_fee: u64,
}Fields
resolved_transactions: Vec<VersionedTransactionResolved>total_required_lamports: u64total_payment_lamports: u64total_solana_estimated_fee: u64Implementations
Sourceimpl BundleProcessor
impl BundleProcessor
Sourcepub fn extract_transactions_to_process(
transactions: &[String],
sign_only_indices: Option<Vec<usize>>,
) -> Result<(Vec<String>, HashMap<usize, usize>), KoraError>
pub fn extract_transactions_to_process( transactions: &[String], sign_only_indices: Option<Vec<usize>>, ) -> Result<(Vec<String>, HashMap<usize, usize>), KoraError>
Extract transactions at specified indices for processing.
Returns (filtered_transactions, index_to_position_map).
If sign_only_indices is None, returns all transactions with all indices.
Sourcepub fn merge_signed_transactions(
original_transactions: &[String],
signed_transactions: Vec<String>,
index_to_position: &HashMap<usize, usize>,
) -> Vec<String>
pub fn merge_signed_transactions( original_transactions: &[String], signed_transactions: Vec<String>, index_to_position: &HashMap<usize, usize>, ) -> Vec<String>
Merge signed transactions back into the original list, preserving order.
index_to_position maps original transaction index -> position in signed_transactions vec.
pub async fn process_bundle<'a>( encoded_txs: &[String], fee_payer: Pubkey, payment_destination: &Pubkey, config: &Config, rpc_client: &Arc<RpcClient>, sig_verify: bool, plugin_context: Option<PluginExecutionContext>, processing_mode: BundleProcessingMode<'a>, ) -> Result<Self, KoraError>
pub async fn sign_all( self, signer: &Arc<Signer>, fee_payer: &Pubkey, rpc_client: &RpcClient, config: &Config, will_send: bool, ) -> Result<Vec<VersionedTransactionResolved>, KoraError>