pub struct CacheUtil;Expand description
Cache utility for Solana RPC calls
Implementations
Sourceimpl CacheUtil
impl CacheUtil
Sourcepub async fn get_account(
config: &Config,
rpc_client: &RpcClient,
pubkey: &Pubkey,
force_refresh: bool,
) -> Result<Account, KoraError>
pub async fn get_account( config: &Config, rpc_client: &RpcClient, pubkey: &Pubkey, force_refresh: bool, ) -> Result<Account, KoraError>
Get account from cache with optional force refresh
Sourcepub async fn get_or_fetch_latest_blockhash(
config: &Config,
rpc_client: &RpcClient,
) -> Result<Hash, KoraError>
pub async fn get_or_fetch_latest_blockhash( config: &Config, rpc_client: &RpcClient, ) -> Result<Hash, KoraError>
Get the latest blockhash, using Redis cache when available.
Reduces RPC load by caching the blockhash with a short TTL (5s). If the cache is unavailable or errors occur, falls back to a direct RPC call.