pub struct LighthouseConfig {
pub enabled: bool,
pub fail_if_transaction_size_overflow: bool,
}Expand description
Configuration for Lighthouse assertions to protect fee payer balance
Fields
enabled: boolEnable Lighthouse assertions for fee payer protection
fail_if_transaction_size_overflow: boolIf true, fail when adding assertion would exceed transaction size limit. If false, skip adding the assertion silently.