pub struct NonceInstructionPolicy {
pub allow_initialize: bool,
pub allow_advance: bool,
pub allow_withdraw: bool,
pub allow_authorize: bool,
}Fields
allow_initialize: boolAllow fee payer to be set as the nonce authority in InitializeNonceAccount instructions
allow_advance: boolAllow fee payer to be the nonce authority in AdvanceNonceAccount instructions
allow_withdraw: boolAllow fee payer to be the nonce authority in WithdrawNonceAccount instructions
Allow fee payer to be the current nonce authority in AuthorizeNonceAccount instructions