pub struct SystemInstructionPolicy {
pub allow_transfer: bool,
pub allow_assign: bool,
pub allow_create_account: bool,
pub allow_allocate: bool,
pub nonce: NonceInstructionPolicy,
}Fields
allow_transfer: boolAllow fee payer to be the sender in System Transfer/TransferWithSeed instructions
allow_assign: boolAllow fee payer to be the authority in System Assign/AssignWithSeed instructions
allow_create_account: boolAllow fee payer to be the payer in System CreateAccount/CreateAccountWithSeed instructions
allow_allocate: boolAllow fee payer to be the account in System Allocate/AllocateWithSeed instructions
nonce: NonceInstructionPolicyNested policy for nonce account operations