pub struct Token2022InstructionPolicy {
pub allow_transfer: bool,
pub allow_burn: bool,
pub allow_close_account: bool,
pub allow_approve: bool,
pub allow_revoke: bool,
pub allow_set_authority: bool,
pub allow_mint_to: bool,
pub allow_initialize_mint: bool,
pub allow_initialize_account: bool,
pub allow_initialize_multisig: bool,
pub allow_freeze_account: bool,
pub allow_thaw_account: bool,
}Fields
allow_transfer: boolAllow fee payer to be the owner in Token2022 Transfer/TransferChecked instructions
allow_burn: boolAllow fee payer to be the owner in Token2022 Burn/BurnChecked instructions
allow_close_account: boolAllow fee payer to be the owner in Token2022 CloseAccount instructions
allow_approve: boolAllow fee payer to be the owner in Token2022 Approve/ApproveChecked instructions
allow_revoke: boolAllow fee payer to be the owner in Token2022 Revoke instructions
Allow fee payer to be the current authority in Token2022 SetAuthority instructions
allow_mint_to: boolAllow fee payer to be the mint authority in Token2022 MintTo/MintToChecked instructions
allow_initialize_mint: boolAllow fee payer to be the mint authority in Token2022 InitializeMint/InitializeMint2 instructions
allow_initialize_account: boolAllow fee payer to be set as the owner in Token2022 InitializeAccount instructions
allow_initialize_multisig: boolAllow fee payer to be a signer in Token2022 InitializeMultisig instructions
allow_freeze_account: boolAllow fee payer to be the freeze authority in Token2022 FreezeAccount instructions
allow_thaw_account: boolAllow fee payer to be the freeze authority in Token2022 ThawAccount instructions