pub struct FeeConfigUtil {}Implementations
Sourceimpl FeeConfigUtil
impl FeeConfigUtil
Sourcepub async fn estimate_kora_fee(
rpc_client: &RpcClient,
transaction: &mut VersionedTransactionResolved,
fee_payer: &Pubkey,
is_payment_required: bool,
price_source: PriceSource,
) -> Result<TotalFeeCalculation, KoraError>
pub async fn estimate_kora_fee( rpc_client: &RpcClient, transaction: &mut VersionedTransactionResolved, fee_payer: &Pubkey, is_payment_required: bool, price_source: PriceSource, ) -> Result<TotalFeeCalculation, KoraError>
Main entry point for fee calculation with Kora’s price model applied
Sourcepub async fn calculate_fee_in_token(
rpc_client: &RpcClient,
fee_in_lamports: u64,
fee_token: Option<&str>,
) -> Result<Option<u64>, KoraError>
pub async fn calculate_fee_in_token( rpc_client: &RpcClient, fee_in_lamports: u64, fee_token: Option<&str>, ) -> Result<Option<u64>, KoraError>
Calculate the fee in a specific token if provided
Sourcepub async fn calculate_fee_payer_outflow(
fee_payer_pubkey: &Pubkey,
transaction: &mut VersionedTransactionResolved,
rpc_client: &RpcClient,
price_source: &PriceSource,
) -> Result<u64, KoraError>
pub async fn calculate_fee_payer_outflow( fee_payer_pubkey: &Pubkey, transaction: &mut VersionedTransactionResolved, rpc_client: &RpcClient, price_source: &PriceSource, ) -> Result<u64, KoraError>
Calculate the total outflow (SOL + SPL token value) that could occur for a fee payer account in a transaction. This includes SOL transfers, account creation, SPL token transfers, and other operations that could drain the fee payer’s balance.