pub struct LighthouseUtil {}Implementations
Sourceimpl LighthouseUtil
impl LighthouseUtil
Sourcepub async fn add_fee_payer_assertion(
transaction: &mut VersionedTransaction,
rpc_client: &RpcClient,
fee_payer: &Pubkey,
estimated_fee: u64,
config: &LighthouseConfig,
will_send: bool,
) -> Result<(), KoraError>
pub async fn add_fee_payer_assertion( transaction: &mut VersionedTransaction, rpc_client: &RpcClient, fee_payer: &Pubkey, estimated_fee: u64, config: &LighthouseConfig, will_send: bool, ) -> Result<(), KoraError>
Add a fee payer balance assertion to a transaction if lighthouse is enabled and not sending. Asserts that fee payer balance >= (current_balance - estimated_fee) at transaction end.
The will_send parameter indicates if the transaction will be sent to the network directly.
When will_send is true, the assertion is skipped because modifying the message would
invalidate existing client signatures.