pub struct KeypairUtil;Expand description
Utility functions for parsing private keys in multiple formats
Implementations
Sourceimpl KeypairUtil
impl KeypairUtil
Sourcepub fn from_private_key_string(private_key: &str) -> Result<Keypair, KoraError>
pub fn from_private_key_string(private_key: &str) -> Result<Keypair, KoraError>
Creates a new keypair from a private key string that can be in multiple formats:
- Base58 encoded string (current format)
- U8Array format: “[0, 1, 2, …]”
- File path to a JSON keypair file
Sourcepub fn from_base58_safe(private_key: &str) -> Result<Keypair, KoraError>
pub fn from_base58_safe(private_key: &str) -> Result<Keypair, KoraError>
Creates a new keypair from a base58-encoded private key string with proper error handling