pub struct TransactionRule { /* private fields */ }Expand description
Rule that limits the total number of transactions per user
Supports both lifetime limits (never resets) and time-windowed limits (resets periodically).
Implementations
Sourceimpl TransactionRule
impl TransactionRule
pub fn new(max: u64, window_seconds: Option<u64>) -> Self
pub fn storage_key(&self, user_id: &str, timestamp: u64) -> String
Sourcepub fn count_increment(&self, _ctx: &mut LimiterContext<'_>) -> u64
pub fn count_increment(&self, _ctx: &mut LimiterContext<'_>) -> u64
How many units to increment for this transaction (always 1)
Sourcepub fn window_seconds(&self) -> Option<u64>
pub fn window_seconds(&self) -> Option<u64>
Time window in seconds
pub fn description(&self) -> String