pub struct SplTokenInstructionPolicy {
pub allow_transfer: bool,
pub allow_burn: bool,
pub allow_close_account: bool,
pub allow_approve: bool,
pub allow_revoke: bool,
pub allow_set_authority: bool,
pub allow_mint_to: bool,
pub allow_initialize_mint: bool,
pub allow_initialize_account: bool,
pub allow_initialize_multisig: bool,
pub allow_freeze_account: bool,
pub allow_thaw_account: bool,
}Fields
allow_transfer: boolAllow fee payer to be the owner in SPL Token Transfer/TransferChecked instructions
allow_burn: boolAllow fee payer to be the owner in SPL Token Burn/BurnChecked instructions
allow_close_account: boolAllow fee payer to be the owner in SPL Token CloseAccount instructions
allow_approve: boolAllow fee payer to be the owner in SPL Token Approve/ApproveChecked instructions
allow_revoke: boolAllow fee payer to be the owner in SPL Token Revoke instructions
Allow fee payer to be the current authority in SPL Token SetAuthority instructions
allow_mint_to: boolAllow fee payer to be the mint authority in SPL Token MintTo/MintToChecked instructions
allow_initialize_mint: boolAllow fee payer to be the mint authority in SPL Token InitializeMint/InitializeMint2 instructions
allow_initialize_account: boolAllow fee payer to be set as the owner in SPL Token InitializeAccount instructions
allow_initialize_multisig: boolAllow fee payer to be a signer in SPL Token InitializeMultisig instructions
allow_freeze_account: boolAllow fee payer to be the freeze authority in SPL Token FreezeAccount instructions
allow_thaw_account: boolAllow fee payer to be the freeze authority in SPL Token ThawAccount instructions