pub struct MockTokenInterface { /* private fields */ }Implementations
Sourceimpl MockTokenInterface
impl MockTokenInterface
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockTokenInterface
impl MockTokenInterface
Sourcepub fn expect_program_id(&mut self) -> &mut Expectation
pub fn expect_program_id(&mut self) -> &mut Expectation
Create an Expectation for mocking the program_id method
Sourcepub fn expect_unpack_token_account(&mut self) -> &mut Expectation
pub fn expect_unpack_token_account(&mut self) -> &mut Expectation
Create an Expectation for mocking the unpack_token_account method
Sourcepub fn expect_create_initialize_account_instruction(
&mut self,
) -> &mut Expectation
pub fn expect_create_initialize_account_instruction( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the create_initialize_account_instruction method
Sourcepub fn expect_create_transfer_instruction(&mut self) -> &mut Expectation
pub fn expect_create_transfer_instruction(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_transfer_instruction method
Sourcepub fn expect_create_transfer_checked_instruction(&mut self) -> &mut Expectation
pub fn expect_create_transfer_checked_instruction(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_transfer_checked_instruction method
Sourcepub fn expect_get_associated_token_address(&mut self) -> &mut Expectation
pub fn expect_get_associated_token_address(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_associated_token_address method
Sourcepub fn expect_create_associated_token_account_instruction(
&mut self,
) -> &mut Expectation
pub fn expect_create_associated_token_account_instruction( &mut self, ) -> &mut Expectation
Create an Expectation for mocking the create_associated_token_account_instruction method
Sourcepub fn expect_unpack_mint(&mut self) -> &mut Expectation
pub fn expect_unpack_mint(&mut self) -> &mut Expectation
Create an Expectation for mocking the unpack_mint method