pub struct VersionedTransactionResolved {
pub transaction: VersionedTransaction,
pub all_account_keys: Vec<Pubkey>,
pub all_instructions: Vec<Instruction>,
/* private fields */
}Expand description
A fully resolved transaction with lookup tables and inner instructions resolved
Fields
transaction: VersionedTransactionall_account_keys: Vec<Pubkey>all_instructions: Vec<Instruction>Implementations
Sourceimpl VersionedTransactionResolved
impl VersionedTransactionResolved
pub async fn from_transaction( transaction: &VersionedTransaction, rpc_client: &RpcClient, sig_verify: bool, ) -> Result<Self, KoraError>
Sourcepub fn from_kora_built_transaction(
transaction: &VersionedTransaction,
) -> Result<Self, KoraError>
pub fn from_kora_built_transaction( transaction: &VersionedTransaction, ) -> Result<Self, KoraError>
Only use this is we built the transaction ourselves, because it won’t do any checks for resolving LUT, etc.
pub fn get_or_parse_system_instructions( &mut self, ) -> Result<&HashMap<ParsedSystemInstructionType, Vec<ParsedSystemInstructionData>>, KoraError>
pub fn get_or_parse_spl_instructions( &mut self, ) -> Result<&HashMap<ParsedSPLInstructionType, Vec<ParsedSPLInstructionData>>, KoraError>
Methods from Deref<Target = VersionedTransaction>
pub fn sanitize(&self) -> Result<(), SanitizeError>
Sourcepub fn version(&self) -> TransactionVersion
pub fn version(&self) -> TransactionVersion
Returns the version of the transaction
Sourcepub fn verify_and_hash_message(&self) -> Result<Hash, TransactionError>
pub fn verify_and_hash_message(&self) -> Result<Hash, TransactionError>
Verify the transaction and hash its message
Sourcepub fn verify_with_results(&self) -> Vec<bool>
pub fn verify_with_results(&self) -> Vec<bool>
Verify the transaction and return a list of verification results
Sourcepub fn uses_durable_nonce(&self) -> bool
pub fn uses_durable_nonce(&self) -> bool
Returns true if transaction begins with an advance nonce instruction.